@@ -258,6 +258,7 @@ HD_DEFINE_PLUGIN (AdvancedBacklightPlugin, advanced_backlight_plugin, STATUSBAR_
   advanced_backlight_plugin_check_init_rotation (vsp);
   /* MERGED from ABL */
   priv->is_n810 = is_n810 ();
+  gettimeofday (&priv->last_beep, NULL);
   advanced_backlight_plugin_load_settings (vsp);
 
 #if 0
@@ -1050,7 +1051,7 @@ advanced_backlight_plugin_dsme_update_brightness (AdvancedBacklightPlugin * vsp)
   if (!priv->has_dsme)
     return;
 
-  value = (priv->brightness_level * 2) + 1;
+  value = (priv->brightness_level * 2);
   if (value <= 2 && !priv->allow_zero)
     value = 3;
 
